bayespy.nodes.VaryingGaussianMarkovChain
========================================

.. currentmodule:: bayespy.nodes

.. autoclass:: VaryingGaussianMarkovChain

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~VaryingGaussianMarkovChain.__init__
      ~VaryingGaussianMarkovChain.add_plate_axis
      ~VaryingGaussianMarkovChain.broadcasting_multiplier
      ~VaryingGaussianMarkovChain.delete
      ~VaryingGaussianMarkovChain.get_gradient
      ~VaryingGaussianMarkovChain.get_mask
      ~VaryingGaussianMarkovChain.get_moments
      ~VaryingGaussianMarkovChain.get_parameters
      ~VaryingGaussianMarkovChain.get_riemannian_gradient
      ~VaryingGaussianMarkovChain.get_shape
      ~VaryingGaussianMarkovChain.has_plotter
      ~VaryingGaussianMarkovChain.initialize_from_parameters
      ~VaryingGaussianMarkovChain.initialize_from_prior
      ~VaryingGaussianMarkovChain.initialize_from_random
      ~VaryingGaussianMarkovChain.initialize_from_value
      ~VaryingGaussianMarkovChain.load
      ~VaryingGaussianMarkovChain.logpdf
      ~VaryingGaussianMarkovChain.lower_bound_contribution
      ~VaryingGaussianMarkovChain.lowerbound
      ~VaryingGaussianMarkovChain.move_plates
      ~VaryingGaussianMarkovChain.observe
      ~VaryingGaussianMarkovChain.pdf
      ~VaryingGaussianMarkovChain.plot
      ~VaryingGaussianMarkovChain.random
      ~VaryingGaussianMarkovChain.rotate
      ~VaryingGaussianMarkovChain.save
      ~VaryingGaussianMarkovChain.set_parameters
      ~VaryingGaussianMarkovChain.set_plotter
      ~VaryingGaussianMarkovChain.show
      ~VaryingGaussianMarkovChain.unobserve
      ~VaryingGaussianMarkovChain.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~VaryingGaussianMarkovChain.dims
      ~VaryingGaussianMarkovChain.plates
      ~VaryingGaussianMarkovChain.plates_multiplier
   
   